from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="UploadedFile")


@attr.s(auto_attribs=True)
class UploadedFile:
    """ """

    filename: str
    id: str
    content_type: Union[Unset, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        filename = self.filename
        id = self.id
        content_type = self.content_type

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "filename": filename,
                "id": id,
            }
        )
        if content_type is not UNSET:
            field_dict["contentType"] = content_type

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        filename = d.pop("filename")

        id = d.pop("id")

        content_type = d.pop("contentType", UNSET)

        uploaded_file = cls(
            filename=filename,
            id=id,
            content_type=content_type,
        )

        return uploaded_file



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.text_with_refs import TextWithRefs
from ..types import UNSET, Unset

T = TypeVar("T", bound="Section")


@attr.s(auto_attribs=True)
class Section:
    """ """

    name: Union[Unset, str] = UNSET
    paragraphs: Union[Unset, List[Union[List[TextWithRefs], TextWithRefs]]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        paragraphs: Union[Unset, List[Union[Dict[str, Any], List[Dict[str, Any]]]]] = UNSET
        if not isinstance(self.paragraphs, Unset):
            paragraphs = []
            for paragraphs_item_data in self.paragraphs:
                if isinstance(paragraphs_item_data, list):
                    paragraphs_item = []
                    for paragraphs_item_type_0_item_data in paragraphs_item_data:
                        paragraphs_item_type_0_item = paragraphs_item_type_0_item_data.to_dict()

                        paragraphs_item.append(paragraphs_item_type_0_item)

                else:
                    paragraphs_item = paragraphs_item_data.to_dict()

                paragraphs.append(paragraphs_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if name is not UNSET:
            field_dict["name"] = name
        if paragraphs is not UNSET:
            field_dict["paragraphs"] = paragraphs

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name", UNSET)

        paragraphs = []
        _paragraphs = d.pop("paragraphs", UNSET)
        for paragraphs_item_data in _paragraphs or []:

            def _parse_paragraphs_item(data: object) -> Union[List[TextWithRefs], TextWithRefs]:
                try:
                    if not isinstance(data, list):
                        raise TypeError()
                    paragraphs_item_type_0 = UNSET
                    _paragraphs_item_type_0 = data
                    for paragraphs_item_type_0_item_data in _paragraphs_item_type_0:
                        paragraphs_item_type_0_item = TextWithRefs.from_dict(paragraphs_item_type_0_item_data)

                        paragraphs_item_type_0.append(paragraphs_item_type_0_item)

                    return paragraphs_item_type_0
                except:  # noqa: E722
                    pass
                if not isinstance(data, dict):
                    raise TypeError()
                paragraphs_item_type_1 = TextWithRefs.from_dict(data)

                return paragraphs_item_type_1

            paragraphs_item = _parse_paragraphs_item(paragraphs_item_data)

            paragraphs.append(paragraphs_item)

        section = cls(
            name=name,
            paragraphs=paragraphs,
        )

        return section



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.author import Author
from ..models.citation_ids import CitationIds
from ..models.citation_scopes import CitationScopes
from ..models.citation_titles import CitationTitles
from ..types import UNSET, Unset

T = TypeVar("T", bound="Citation")


@attr.s(auto_attribs=True)
class Citation:
    """ """

    main_title: Union[Unset, str] = UNSET
    authors: Union[Unset, List[Author]] = UNSET
    titles: Union[Unset, CitationTitles] = UNSET
    published: Union[Unset, datetime.date] = UNSET
    publisher: Union[Unset, str] = UNSET
    scopes: Union[Unset, CitationScopes] = UNSET
    ids: Union[Unset, CitationIds] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        main_title = self.main_title
        authors: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.authors, Unset):
            authors = []
            for authors_item_data in self.authors:
                authors_item = authors_item_data.to_dict()

                authors.append(authors_item)

        titles: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.titles, Unset):
            titles = self.titles.to_dict()

        published: Union[Unset, str] = UNSET
        if not isinstance(self.published, Unset):
            published = self.published.isoformat()

        publisher = self.publisher
        scopes: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.scopes, Unset):
            scopes = self.scopes.to_dict()

        ids: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.ids, Unset):
            ids = self.ids.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if main_title is not UNSET:
            field_dict["main_title"] = main_title
        if authors is not UNSET:
            field_dict["authors"] = authors
        if titles is not UNSET:
            field_dict["titles"] = titles
        if published is not UNSET:
            field_dict["published"] = published
        if publisher is not UNSET:
            field_dict["publisher"] = publisher
        if scopes is not UNSET:
            field_dict["scopes"] = scopes
        if ids is not UNSET:
            field_dict["ids"] = ids

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        main_title = d.pop("main_title", UNSET)

        authors = []
        _authors = d.pop("authors", UNSET)
        for authors_item_data in _authors or []:
            authors_item = Author.from_dict(authors_item_data)

            authors.append(authors_item)

        _titles = d.pop("titles", UNSET)
        titles: Union[Unset, CitationTitles]
        if isinstance(_titles, Unset):
            titles = UNSET
        else:
            titles = CitationTitles.from_dict(_titles)

        _published = d.pop("published", UNSET)
        published: Union[Unset, datetime.date]
        if isinstance(_published, Unset):
            published = UNSET
        else:
            published = isoparse(_published).date()

        publisher = d.pop("publisher", UNSET)

        _scopes = d.pop("scopes", UNSET)
        scopes: Union[Unset, CitationScopes]
        if isinstance(_scopes, Unset):
            scopes = UNSET
        else:
            scopes = CitationScopes.from_dict(_scopes)

        _ids = d.pop("ids", UNSET)
        ids: Union[Unset, CitationIds]
        if isinstance(_ids, Unset):
            ids = UNSET
        else:
            ids = CitationIds.from_dict(_ids)

        citation = cls(
            main_title=main_title,
            authors=authors,
            titles=titles,
            published=published,
            publisher=publisher,
            scopes=scopes,
            ids=ids,
        )

        return citation



""" Contains all the data models used in inputs/outputs """

from .address import Address
from .affiliation import Affiliation
from .article import Article
from .article_citations import ArticleCitations
from .author import Author
from .citation import Citation
from .citation_ids import CitationIds
from .citation_scopes import CitationScopes
from .citation_titles import CitationTitles
from .pers_name import PersName
from .process_form import ProcessForm
from .ref import Ref
from .section import Section
from .text_with_refs import TextWithRefs
from .uploaded_file import UploadedFile
